# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clusterfuzz/_internal/protos/untrusted_runner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='clusterfuzz/_internal/protos/untrusted_runner.proto',
  package='',
  syntax='proto2',
  serialized_options=b'Z#clusterfuzz/protos/untrusted_runner',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3clusterfuzz/_internal/protos/untrusted_runner.proto\x1a\x19google/protobuf/any.proto\"\x12\n\x10GetStatusRequest\"K\n\x11GetStatusResponse\x12\x10\n\x08revision\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\x04\x12\x10\n\x08\x62ot_name\x18\x03 \x01(\t\"o\n\rProcessResult\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\x12\x13\n\x0breturn_code\x18\x02 \x01(\x05\x12\x0e\n\x06output\x18\x03 \x01(\x0c\x12\x15\n\rtime_executed\x18\x04 \x01(\x01\x12\x11\n\ttimed_out\x18\x05 \x01(\x08\"\xb5\x01\n\x12SetupBuildResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x10\n\x08\x61pp_path\x18\x02 \x01(\t\x12\x16\n\x0e\x61pp_path_debug\x18\x03 \x01(\t\x12\x0f\n\x07\x61pp_dir\x18\x04 \x01(\t\x12\x11\n\tbuild_dir\x18\x05 \x01(\t\x12\x11\n\tbuild_url\x18\x06 \x01(\t\x12\x13\n\x0b\x66uzz_target\x18\x07 \x01(\t\x12\x19\n\x11\x66uzz_target_count\x18\x08 \x01(\x05\"\xe9\x01\n\x18SetupRegularBuildRequest\x12\x16\n\x0e\x62\x61se_build_dir\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x02 \x01(\x03\x12\x11\n\tbuild_url\x18\x03 \x01(\t\x12\x44\n\x0etarget_weights\x18\x04 \x03(\x0b\x32,.SetupRegularBuildRequest.TargetWeightsEntry\x12\x14\n\x0c\x62uild_prefix\x18\x05 \x01(\t\x1a\x34\n\x12TargetWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x90\x02\n\x11RunProcessRequest\x12\x0f\n\x07\x63mdline\x18\x01 \x01(\t\x12!\n\x19\x63urrent_working_directory\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x12\n\nneed_shell\x18\x04 \x01(\x08\x12\x10\n\x08gestures\x18\x05 \x03(\t\x12\x31\n\x08\x65nv_copy\x18\x06 \x03(\x0b\x32\x1f.RunProcessRequest.EnvCopyEntry\x12\x14\n\x0ctestcase_run\x18\x07 \x01(\x08\x12\x17\n\x0fignore_children\x18\x08 \x01(\x08\x1a.\n\x0c\x45nvCopyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x12RunProcessResponse\x12\x13\n\x0breturn_code\x18\x01 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x02 \x01(\x01\x12\x0e\n\x06output\x18\x03 \x01(\t\"\xb5\x01\n\tPopenArgs\x12\x0f\n\x07\x62ufsize\x18\x01 \x01(\x05\x12\x12\n\nexecutable\x18\x02 \x01(\t\x12\r\n\x05shell\x18\x03 \x01(\x08\x12\x0b\n\x03\x63wd\x18\x04 \x01(\t\x12 \n\x03\x65nv\x18\x05 \x03(\x0b\x32\x13.PopenArgs.EnvEntry\x12\x19\n\nenv_is_set\x18\x06 \x01(\x08:\x05\x66\x61lse\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x01\n\x11RunAndWaitRequest\x12\x17\n\x0f\x65xecutable_path\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ult_args\x18\x02 \x03(\t\x12\x17\n\x0f\x61\x64\x64itional_args\x18\x03 \x03(\t\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12\x1d\n\x15terminate_before_kill\x18\x05 \x01(\x08\x12\x1b\n\x13terminate_wait_time\x18\x06 \x01(\x01\x12\x12\n\ninput_data\x18\x07 \x01(\x0c\x12\x1e\n\npopen_args\x18\x08 \x01(\x0b\x32\n.PopenArgs\x12\x16\n\x0emax_stdout_len\x18\t \x01(\r\"4\n\x12RunAndWaitResponse\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.ProcessResult\"(\n\x14\x46indBuildFileRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"9\n\x15\x46indBuildFileResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x11\n\tfile_path\x18\x02 \x01(\t\"D\n\x16\x43reateDirectoryRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x1c\n\x14\x63reate_intermediates\x18\x02 \x01(\x08\")\n\x17\x43reateDirectoryResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"8\n\x16RemoveDirectoryRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x10\n\x08recreate\x18\x02 \x01(\x08\")\n\x17RemoveDirectoryResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"\x19\n\tFileChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"$\n\x12\x43opyFileToResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"#\n\x13\x43opyFileFromRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"w\n\x18UpdateEnvironmentRequest\x12/\n\x03\x65nv\x18\x01 \x03(\x0b\x32\".UpdateEnvironmentRequest.EnvEntry\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1b\n\x19UpdateEnvironmentResponse\"\x15\n\x13UpdateSourceRequest\"\x16\n\x14UpdateSourceResponse\"a\n\x1aSymbolizeStacktraceRequest\x12%\n\x1dunsymbolized_crash_stacktrace\x18\x01 \x01(\t\x12\x1c\n\x14\x65nable_inline_frames\x18\x02 \x01(\x08\"<\n\x1bSymbolizeStacktraceResponse\x12\x1d\n\x15symbolized_stacktrace\x18\x01 \x01(\t\"3\n\x10ListFilesRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\trecursive\x18\x02 \x01(\x08\"\'\n\x11ListFilesResponse\x12\x12\n\nfile_paths\x18\x01 \x03(\t\"%\n\x15GetFuzzTargetsRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"3\n\x16GetFuzzTargetsResponse\x12\x19\n\x11\x66uzz_target_paths\x18\x01 \x03(\t\"\x91\x01\n\x0b\x43orpusCrash\x12\x13\n\x0b\x63rash_state\x18\x01 \x01(\t\x12\x12\n\ncrash_type\x18\x02 \x01(\t\x12\x15\n\rcrash_address\x18\x03 \x01(\t\x12\x18\n\x10\x63rash_stacktrace\x18\x04 \x01(\t\x12\x11\n\tunit_path\x18\x05 \x01(\t\x12\x15\n\rsecurity_flag\x18\x06 \x01(\x08\"\xd8\x01\n\x0c\x43overageInfo\x12\x19\n\x11\x63orpus_size_units\x18\x05 \x01(\x03\x12\x19\n\x11\x63orpus_size_bytes\x18\x06 \x01(\x03\x12\x17\n\x0f\x63orpus_location\x18\x07 \x01(\t\x12\x1e\n\x16\x63orpus_backup_location\x18\x08 \x01(\t\x12\x1d\n\x15quarantine_size_units\x18\t \x01(\x03\x12\x1d\n\x15quarantine_size_bytes\x18\n \x01(\x03\x12\x1b\n\x13quarantine_location\x18\x0b \x01(\t\"p\n\x14\x43rossPollinateFuzzer\x12 \n\x0b\x66uzz_target\x18\x01 \x01(\x0b\x32\x0b.FuzzTarget\x12\x1a\n\x12\x62\x61\x63kup_bucket_name\x18\x02 \x01(\t\x12\x1a\n\x12\x63orpus_engine_name\x18\x03 \x01(\t\"\x9f\x01\n\x12PruneCorpusRequest\x12 \n\x0b\x66uzz_target\x18\x01 \x01(\x0b\x32\x0b.FuzzTarget\x12\x36\n\x17\x63ross_pollinate_fuzzers\x18\x02 \x03(\x0b\x32\x15.CrossPollinateFuzzer\x12\x1d\n\x15last_execution_failed\x18\x04 \x01(\x08\x12\x10\n\x08revision\x18\x05 \x01(\x03\"\xc1\x01\n\x13PruneCorpusResponse\x12$\n\rcoverage_info\x18\x01 \x01(\x0b\x32\r.CoverageInfo\x12\x1d\n\x07\x63rashes\x18\x02 \x03(\x0b\x32\x0c.CorpusCrash\x12\x1a\n\x12\x66uzzer_binary_name\x18\x03 \x01(\t\x12\x10\n\x08revision\x18\x04 \x01(\x03\x12\x37\n\x17\x63ross_pollination_stats\x18\x05 \x01(\x0b\x32\x16.CrossPollinationStats\"\x1b\n\x0bStatRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x8a\x02\n\x15\x43rossPollinationStats\x12\x1e\n\x16project_qualified_name\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0f\n\x07sources\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x01(\t\x12\x1b\n\x13initial_corpus_size\x18\x05 \x01(\x05\x12\x13\n\x0b\x63orpus_size\x18\x06 \x01(\x05\x12\x1d\n\x15initial_edge_coverage\x18\x07 \x01(\x05\x12\x15\n\redge_coverage\x18\x08 \x01(\x05\x12 \n\x18initial_feature_coverage\x18\t \x01(\x05\x12\x18\n\x10\x66\x65\x61ture_coverage\x18\n \x01(\x05\"v\n\x0cStatResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x0f\n\x07st_mode\x18\x02 \x01(\r\x12\x0f\n\x07st_size\x18\x03 \x01(\x04\x12\x10\n\x08st_atime\x18\x05 \x01(\x01\x12\x10\n\x08st_mtime\x18\x06 \x01(\x01\x12\x10\n\x08st_ctime\x18\x07 \x01(\x01\"+\n)TerminateStaleApplicationInstancesRequest\",\n*TerminateStaleApplicationInstancesResponse\"\x19\n\x17ResetEnvironmentRequest\"\x1a\n\x18ResetEnvironmentResponse\"=\n\nFuzzTarget\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12\x0e\n\x06\x62inary\x18\x03 \x01(\t\"\xeb\x01\n\x16ProcessTestcaseRequest\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t\x12\x34\n\toperation\x18\x02 \x01(\x0e\x32!.ProcessTestcaseRequest.Operation\x12\x13\n\x0btarget_name\x18\x03 \x01(\t\x12\x11\n\targuments\x18\x04 \x03(\t\x12\x15\n\rtestcase_path\x18\x05 \x01(\t\x12\x13\n\x0boutput_path\x18\x06 \x01(\t\x12\x0f\n\x07timeout\x18\x07 \x01(\x04\"&\n\tOperation\x12\x0c\n\x08MINIMIZE\x10\x00\x12\x0b\n\x07\x43LEANSE\x10\x01\"d\n\x15\x45ngineReproduceResult\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\x12\x13\n\x0breturn_code\x18\x02 \x01(\x03\x12\x15\n\rtime_executed\x18\x03 \x01(\x01\x12\x0e\n\x06output\x18\x04 \x01(\t\"s\n\x11\x45ngineFuzzRequest\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\x12\x1d\n\x15sync_corpus_directory\x18\x03 \x01(\t\x12\x1a\n\x12testcase_directory\x18\x04 \x01(\t\"a\n\x0b\x45ngineCrash\x12\x12\n\ninput_path\x18\x01 \x01(\t\x12\x12\n\nstacktrace\x18\x02 \x01(\t\x12\x16\n\x0ereproduce_args\x18\x03 \x03(\t\x12\x12\n\ncrash_time\x18\x04 \x01(\x01\"\xd7\x03\n\x12\x45ngineFuzzResponse\x12\x0c\n\x04logs\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x1d\n\x07\x63rashes\x18\x03 \x03(\x0b\x32\x0c.EngineCrash\x12-\n\x05stats\x18\x04 \x03(\x0b\x32\x1e.EngineFuzzResponse.StatsEntry\x12\x15\n\rtime_executed\x18\x05 \x01(\x01\x12@\n\x0f\x66uzzer_metadata\x18\x06 \x03(\x0b\x32\'.EngineFuzzResponse.FuzzerMetadataEntry\x12\x37\n\nstrategies\x18\x07 \x03(\x0b\x32#.EngineFuzzResponse.StrategiesEntry\x1a\x42\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1a\x35\n\x13\x46uzzerMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aG\n\x0fStrategiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\"x\n\x16\x45ngineReproduceRequest\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\x12\x15\n\rtestcase_path\x18\x03 \x01(\t\x12\x11\n\targuments\x18\x04 \x03(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x01\x32\xa1\n\n\x0fUntrustedRunner\x12\x32\n\tGetStatus\x12\x11.GetStatusRequest\x1a\x12.GetStatusResponse\x12\x43\n\x11SetupRegularBuild\x12\x19.SetupRegularBuildRequest\x1a\x13.SetupBuildResponse\x12\x35\n\nRunProcess\x12\x12.RunProcessRequest\x1a\x13.RunProcessResponse\x12\x35\n\nRunAndWait\x12\x12.RunAndWaitRequest\x1a\x13.RunAndWaitResponse\x12\x44\n\x0f\x43reateDirectory\x12\x17.CreateDirectoryRequest\x1a\x18.CreateDirectoryResponse\x12\x44\n\x0fRemoveDirectory\x12\x17.RemoveDirectoryRequest\x1a\x18.RemoveDirectoryResponse\x12\x32\n\tListFiles\x12\x11.ListFilesRequest\x1a\x12.ListFilesResponse\x12/\n\nCopyFileTo\x12\n.FileChunk\x1a\x13.CopyFileToResponse(\x01\x12\x32\n\x0c\x43opyFileFrom\x12\x14.CopyFileFromRequest\x1a\n.FileChunk0\x01\x12#\n\x04Stat\x12\x0c.StatRequest\x1a\r.StatResponse\x12J\n\x11UpdateEnvironment\x12\x19.UpdateEnvironmentRequest\x1a\x1a.UpdateEnvironmentResponse\x12G\n\x10ResetEnvironment\x12\x18.ResetEnvironmentRequest\x1a\x19.ResetEnvironmentResponse\x12;\n\x0cUpdateSource\x12\x14.UpdateSourceRequest\x1a\x15.UpdateSourceResponse\x12P\n\x13SymbolizeStacktrace\x12\x1b.SymbolizeStacktraceRequest\x1a\x1c.SymbolizeStacktraceResponse\x12}\n\"TerminateStaleApplicationInstances\x12*.TerminateStaleApplicationInstancesRequest\x1a+.TerminateStaleApplicationInstancesResponse\x12\x41\n\x0eGetFuzzTargets\x12\x16.GetFuzzTargetsRequest\x1a\x17.GetFuzzTargetsResponse\x12\x38\n\x0bPruneCorpus\x12\x13.PruneCorpusRequest\x1a\x14.PruneCorpusResponse\x12\x42\n\x0fProcessTestcase\x12\x17.ProcessTestcaseRequest\x1a\x16.EngineReproduceResult\x12\x35\n\nEngineFuzz\x12\x12.EngineFuzzRequest\x1a\x13.EngineFuzzResponse\x12\x42\n\x0f\x45ngineReproduce\x12\x17.EngineReproduceRequest\x1a\x16.EngineReproduceResultB%Z#clusterfuzz/protos/untrusted_runner'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])



_PROCESSTESTCASEREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='ProcessTestcaseRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MINIMIZE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4180,
  serialized_end=4218,
)
_sym_db.RegisterEnumDescriptor(_PROCESSTESTCASEREQUEST_OPERATION)


_GETSTATUSREQUEST = _descriptor.Descriptor(
  name='GetStatusRequest',
  full_name='GetStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=100,
)


_GETSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetStatusResponse',
  full_name='GetStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='revision', full_name='GetStatusResponse.revision', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='GetStatusResponse.start_time', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_name', full_name='GetStatusResponse.bot_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=177,
)


_PROCESSRESULT = _descriptor.Descriptor(
  name='ProcessResult',
  full_name='ProcessResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='ProcessResult.command', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_code', full_name='ProcessResult.return_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='ProcessResult.output', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_executed', full_name='ProcessResult.time_executed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timed_out', full_name='ProcessResult.timed_out', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=290,
)


_SETUPBUILDRESPONSE = _descriptor.Descriptor(
  name='SetupBuildResponse',
  full_name='SetupBuildResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='SetupBuildResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_path', full_name='SetupBuildResponse.app_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_path_debug', full_name='SetupBuildResponse.app_path_debug', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_dir', full_name='SetupBuildResponse.app_dir', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_dir', full_name='SetupBuildResponse.build_dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_url', full_name='SetupBuildResponse.build_url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzz_target', full_name='SetupBuildResponse.fuzz_target', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzz_target_count', full_name='SetupBuildResponse.fuzz_target_count', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=474,
)


_SETUPREGULARBUILDREQUEST_TARGETWEIGHTSENTRY = _descriptor.Descriptor(
  name='TargetWeightsEntry',
  full_name='SetupRegularBuildRequest.TargetWeightsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='SetupRegularBuildRequest.TargetWeightsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='SetupRegularBuildRequest.TargetWeightsEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=710,
)

_SETUPREGULARBUILDREQUEST = _descriptor.Descriptor(
  name='SetupRegularBuildRequest',
  full_name='SetupRegularBuildRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_build_dir', full_name='SetupRegularBuildRequest.base_build_dir', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='SetupRegularBuildRequest.revision', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_url', full_name='SetupRegularBuildRequest.build_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_weights', full_name='SetupRegularBuildRequest.target_weights', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_prefix', full_name='SetupRegularBuildRequest.build_prefix', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SETUPREGULARBUILDREQUEST_TARGETWEIGHTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=710,
)


_RUNPROCESSREQUEST_ENVCOPYENTRY = _descriptor.Descriptor(
  name='EnvCopyEntry',
  full_name='RunProcessRequest.EnvCopyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='RunProcessRequest.EnvCopyEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='RunProcessRequest.EnvCopyEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=985,
)

_RUNPROCESSREQUEST = _descriptor.Descriptor(
  name='RunProcessRequest',
  full_name='RunProcessRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmdline', full_name='RunProcessRequest.cmdline', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_working_directory', full_name='RunProcessRequest.current_working_directory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='RunProcessRequest.timeout', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_shell', full_name='RunProcessRequest.need_shell', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gestures', full_name='RunProcessRequest.gestures', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_copy', full_name='RunProcessRequest.env_copy', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testcase_run', full_name='RunProcessRequest.testcase_run', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_children', full_name='RunProcessRequest.ignore_children', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RUNPROCESSREQUEST_ENVCOPYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=985,
)


_RUNPROCESSRESPONSE = _descriptor.Descriptor(
  name='RunProcessResponse',
  full_name='RunProcessResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='return_code', full_name='RunProcessResponse.return_code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_time', full_name='RunProcessResponse.execution_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='RunProcessResponse.output', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1068,
)


_POPENARGS_ENVENTRY = _descriptor.Descriptor(
  name='EnvEntry',
  full_name='PopenArgs.EnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PopenArgs.EnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PopenArgs.EnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1252,
)

_POPENARGS = _descriptor.Descriptor(
  name='PopenArgs',
  full_name='PopenArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bufsize', full_name='PopenArgs.bufsize', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executable', full_name='PopenArgs.executable', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shell', full_name='PopenArgs.shell', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cwd', full_name='PopenArgs.cwd', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env', full_name='PopenArgs.env', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_is_set', full_name='PopenArgs.env_is_set', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_POPENARGS_ENVENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1252,
)


_RUNANDWAITREQUEST = _descriptor.Descriptor(
  name='RunAndWaitRequest',
  full_name='RunAndWaitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='executable_path', full_name='RunAndWaitRequest.executable_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_args', full_name='RunAndWaitRequest.default_args', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_args', full_name='RunAndWaitRequest.additional_args', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='RunAndWaitRequest.timeout', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminate_before_kill', full_name='RunAndWaitRequest.terminate_before_kill', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminate_wait_time', full_name='RunAndWaitRequest.terminate_wait_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_data', full_name='RunAndWaitRequest.input_data', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='popen_args', full_name='RunAndWaitRequest.popen_args', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_stdout_len', full_name='RunAndWaitRequest.max_stdout_len', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1499,
)


_RUNANDWAITRESPONSE = _descriptor.Descriptor(
  name='RunAndWaitResponse',
  full_name='RunAndWaitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='RunAndWaitResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1553,
)


_FINDBUILDFILEREQUEST = _descriptor.Descriptor(
  name='FindBuildFileRequest',
  full_name='FindBuildFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='FindBuildFileRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1555,
  serialized_end=1595,
)


_FINDBUILDFILERESPONSE = _descriptor.Descriptor(
  name='FindBuildFileResponse',
  full_name='FindBuildFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='found', full_name='FindBuildFileResponse.found', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='FindBuildFileResponse.file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1597,
  serialized_end=1654,
)


_CREATEDIRECTORYREQUEST = _descriptor.Descriptor(
  name='CreateDirectoryRequest',
  full_name='CreateDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='CreateDirectoryRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_intermediates', full_name='CreateDirectoryRequest.create_intermediates', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1656,
  serialized_end=1724,
)


_CREATEDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='CreateDirectoryResponse',
  full_name='CreateDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CreateDirectoryResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1726,
  serialized_end=1767,
)


_REMOVEDIRECTORYREQUEST = _descriptor.Descriptor(
  name='RemoveDirectoryRequest',
  full_name='RemoveDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='RemoveDirectoryRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recreate', full_name='RemoveDirectoryRequest.recreate', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1825,
)


_REMOVEDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='RemoveDirectoryResponse',
  full_name='RemoveDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='RemoveDirectoryResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1827,
  serialized_end=1868,
)


_FILECHUNK = _descriptor.Descriptor(
  name='FileChunk',
  full_name='FileChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='FileChunk.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1895,
)


_COPYFILETORESPONSE = _descriptor.Descriptor(
  name='CopyFileToResponse',
  full_name='CopyFileToResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CopyFileToResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1897,
  serialized_end=1933,
)


_COPYFILEFROMREQUEST = _descriptor.Descriptor(
  name='CopyFileFromRequest',
  full_name='CopyFileFromRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='CopyFileFromRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1935,
  serialized_end=1970,
)


_UPDATEENVIRONMENTREQUEST_ENVENTRY = _descriptor.Descriptor(
  name='EnvEntry',
  full_name='UpdateEnvironmentRequest.EnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='UpdateEnvironmentRequest.EnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='UpdateEnvironmentRequest.EnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1252,
)

_UPDATEENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='UpdateEnvironmentRequest',
  full_name='UpdateEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='env', full_name='UpdateEnvironmentRequest.env', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEENVIRONMENTREQUEST_ENVENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2091,
)


_UPDATEENVIRONMENTRESPONSE = _descriptor.Descriptor(
  name='UpdateEnvironmentResponse',
  full_name='UpdateEnvironmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2093,
  serialized_end=2120,
)


_UPDATESOURCEREQUEST = _descriptor.Descriptor(
  name='UpdateSourceRequest',
  full_name='UpdateSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2122,
  serialized_end=2143,
)


_UPDATESOURCERESPONSE = _descriptor.Descriptor(
  name='UpdateSourceResponse',
  full_name='UpdateSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2145,
  serialized_end=2167,
)


_SYMBOLIZESTACKTRACEREQUEST = _descriptor.Descriptor(
  name='SymbolizeStacktraceRequest',
  full_name='SymbolizeStacktraceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unsymbolized_crash_stacktrace', full_name='SymbolizeStacktraceRequest.unsymbolized_crash_stacktrace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_inline_frames', full_name='SymbolizeStacktraceRequest.enable_inline_frames', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2169,
  serialized_end=2266,
)


_SYMBOLIZESTACKTRACERESPONSE = _descriptor.Descriptor(
  name='SymbolizeStacktraceResponse',
  full_name='SymbolizeStacktraceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbolized_stacktrace', full_name='SymbolizeStacktraceResponse.symbolized_stacktrace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2328,
)


_LISTFILESREQUEST = _descriptor.Descriptor(
  name='ListFilesRequest',
  full_name='ListFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ListFilesRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='ListFilesRequest.recursive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2330,
  serialized_end=2381,
)


_LISTFILESRESPONSE = _descriptor.Descriptor(
  name='ListFilesResponse',
  full_name='ListFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_paths', full_name='ListFilesResponse.file_paths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2383,
  serialized_end=2422,
)


_GETFUZZTARGETSREQUEST = _descriptor.Descriptor(
  name='GetFuzzTargetsRequest',
  full_name='GetFuzzTargetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='GetFuzzTargetsRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2424,
  serialized_end=2461,
)


_GETFUZZTARGETSRESPONSE = _descriptor.Descriptor(
  name='GetFuzzTargetsResponse',
  full_name='GetFuzzTargetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fuzz_target_paths', full_name='GetFuzzTargetsResponse.fuzz_target_paths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2463,
  serialized_end=2514,
)


_CORPUSCRASH = _descriptor.Descriptor(
  name='CorpusCrash',
  full_name='CorpusCrash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='crash_state', full_name='CorpusCrash.crash_state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crash_type', full_name='CorpusCrash.crash_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crash_address', full_name='CorpusCrash.crash_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crash_stacktrace', full_name='CorpusCrash.crash_stacktrace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_path', full_name='CorpusCrash.unit_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_flag', full_name='CorpusCrash.security_flag', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2517,
  serialized_end=2662,
)


_COVERAGEINFO = _descriptor.Descriptor(
  name='CoverageInfo',
  full_name='CoverageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='corpus_size_units', full_name='CoverageInfo.corpus_size_units', index=0,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corpus_size_bytes', full_name='CoverageInfo.corpus_size_bytes', index=1,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corpus_location', full_name='CoverageInfo.corpus_location', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corpus_backup_location', full_name='CoverageInfo.corpus_backup_location', index=3,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quarantine_size_units', full_name='CoverageInfo.quarantine_size_units', index=4,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quarantine_size_bytes', full_name='CoverageInfo.quarantine_size_bytes', index=5,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quarantine_location', full_name='CoverageInfo.quarantine_location', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2665,
  serialized_end=2881,
)


_CROSSPOLLINATEFUZZER = _descriptor.Descriptor(
  name='CrossPollinateFuzzer',
  full_name='CrossPollinateFuzzer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fuzz_target', full_name='CrossPollinateFuzzer.fuzz_target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_bucket_name', full_name='CrossPollinateFuzzer.backup_bucket_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corpus_engine_name', full_name='CrossPollinateFuzzer.corpus_engine_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2883,
  serialized_end=2995,
)


_PRUNECORPUSREQUEST = _descriptor.Descriptor(
  name='PruneCorpusRequest',
  full_name='PruneCorpusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fuzz_target', full_name='PruneCorpusRequest.fuzz_target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_pollinate_fuzzers', full_name='PruneCorpusRequest.cross_pollinate_fuzzers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_execution_failed', full_name='PruneCorpusRequest.last_execution_failed', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='PruneCorpusRequest.revision', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2998,
  serialized_end=3157,
)


_PRUNECORPUSRESPONSE = _descriptor.Descriptor(
  name='PruneCorpusResponse',
  full_name='PruneCorpusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='coverage_info', full_name='PruneCorpusResponse.coverage_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crashes', full_name='PruneCorpusResponse.crashes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzer_binary_name', full_name='PruneCorpusResponse.fuzzer_binary_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='PruneCorpusResponse.revision', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_pollination_stats', full_name='PruneCorpusResponse.cross_pollination_stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3160,
  serialized_end=3353,
)


_STATREQUEST = _descriptor.Descriptor(
  name='StatRequest',
  full_name='StatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='StatRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3355,
  serialized_end=3382,
)


_CROSSPOLLINATIONSTATS = _descriptor.Descriptor(
  name='CrossPollinationStats',
  full_name='CrossPollinationStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_qualified_name', full_name='CrossPollinationStats.project_qualified_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='CrossPollinationStats.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='CrossPollinationStats.sources', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CrossPollinationStats.tags', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_corpus_size', full_name='CrossPollinationStats.initial_corpus_size', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corpus_size', full_name='CrossPollinationStats.corpus_size', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_edge_coverage', full_name='CrossPollinationStats.initial_edge_coverage', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edge_coverage', full_name='CrossPollinationStats.edge_coverage', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_feature_coverage', full_name='CrossPollinationStats.initial_feature_coverage', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_coverage', full_name='CrossPollinationStats.feature_coverage', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3385,
  serialized_end=3651,
)


_STATRESPONSE = _descriptor.Descriptor(
  name='StatResponse',
  full_name='StatResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='StatResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_mode', full_name='StatResponse.st_mode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_size', full_name='StatResponse.st_size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_atime', full_name='StatResponse.st_atime', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_mtime', full_name='StatResponse.st_mtime', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_ctime', full_name='StatResponse.st_ctime', index=5,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3653,
  serialized_end=3771,
)


_TERMINATESTALEAPPLICATIONINSTANCESREQUEST = _descriptor.Descriptor(
  name='TerminateStaleApplicationInstancesRequest',
  full_name='TerminateStaleApplicationInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3773,
  serialized_end=3816,
)


_TERMINATESTALEAPPLICATIONINSTANCESRESPONSE = _descriptor.Descriptor(
  name='TerminateStaleApplicationInstancesResponse',
  full_name='TerminateStaleApplicationInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3818,
  serialized_end=3862,
)


_RESETENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='ResetEnvironmentRequest',
  full_name='ResetEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3864,
  serialized_end=3889,
)


_RESETENVIRONMENTRESPONSE = _descriptor.Descriptor(
  name='ResetEnvironmentResponse',
  full_name='ResetEnvironmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3891,
  serialized_end=3917,
)


_FUZZTARGET = _descriptor.Descriptor(
  name='FuzzTarget',
  full_name='FuzzTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine', full_name='FuzzTarget.engine', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project', full_name='FuzzTarget.project', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary', full_name='FuzzTarget.binary', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3919,
  serialized_end=3980,
)


_PROCESSTESTCASEREQUEST = _descriptor.Descriptor(
  name='ProcessTestcaseRequest',
  full_name='ProcessTestcaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine', full_name='ProcessTestcaseRequest.engine', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='ProcessTestcaseRequest.operation', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_name', full_name='ProcessTestcaseRequest.target_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='ProcessTestcaseRequest.arguments', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testcase_path', full_name='ProcessTestcaseRequest.testcase_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_path', full_name='ProcessTestcaseRequest.output_path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='ProcessTestcaseRequest.timeout', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSTESTCASEREQUEST_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3983,
  serialized_end=4218,
)


_ENGINEREPRODUCERESULT = _descriptor.Descriptor(
  name='EngineReproduceResult',
  full_name='EngineReproduceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='EngineReproduceResult.command', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_code', full_name='EngineReproduceResult.return_code', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_executed', full_name='EngineReproduceResult.time_executed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='EngineReproduceResult.output', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4220,
  serialized_end=4320,
)


_ENGINEFUZZREQUEST = _descriptor.Descriptor(
  name='EngineFuzzRequest',
  full_name='EngineFuzzRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine', full_name='EngineFuzzRequest.engine', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_name', full_name='EngineFuzzRequest.target_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sync_corpus_directory', full_name='EngineFuzzRequest.sync_corpus_directory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testcase_directory', full_name='EngineFuzzRequest.testcase_directory', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4322,
  serialized_end=4437,
)


_ENGINECRASH = _descriptor.Descriptor(
  name='EngineCrash',
  full_name='EngineCrash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_path', full_name='EngineCrash.input_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stacktrace', full_name='EngineCrash.stacktrace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reproduce_args', full_name='EngineCrash.reproduce_args', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crash_time', full_name='EngineCrash.crash_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4439,
  serialized_end=4536,
)


_ENGINEFUZZRESPONSE_STATSENTRY = _descriptor.Descriptor(
  name='StatsEntry',
  full_name='EngineFuzzResponse.StatsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='EngineFuzzResponse.StatsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='EngineFuzzResponse.StatsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4816,
  serialized_end=4882,
)

_ENGINEFUZZRESPONSE_FUZZERMETADATAENTRY = _descriptor.Descriptor(
  name='FuzzerMetadataEntry',
  full_name='EngineFuzzResponse.FuzzerMetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='EngineFuzzResponse.FuzzerMetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='EngineFuzzResponse.FuzzerMetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4884,
  serialized_end=4937,
)

_ENGINEFUZZRESPONSE_STRATEGIESENTRY = _descriptor.Descriptor(
  name='StrategiesEntry',
  full_name='EngineFuzzResponse.StrategiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='EngineFuzzResponse.StrategiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='EngineFuzzResponse.StrategiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4939,
  serialized_end=5010,
)

_ENGINEFUZZRESPONSE = _descriptor.Descriptor(
  name='EngineFuzzResponse',
  full_name='EngineFuzzResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='EngineFuzzResponse.logs', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='EngineFuzzResponse.command', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crashes', full_name='EngineFuzzResponse.crashes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='EngineFuzzResponse.stats', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_executed', full_name='EngineFuzzResponse.time_executed', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuzzer_metadata', full_name='EngineFuzzResponse.fuzzer_metadata', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategies', full_name='EngineFuzzResponse.strategies', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ENGINEFUZZRESPONSE_STATSENTRY, _ENGINEFUZZRESPONSE_FUZZERMETADATAENTRY, _ENGINEFUZZRESPONSE_STRATEGIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4539,
  serialized_end=5010,
)


_ENGINEREPRODUCEREQUEST = _descriptor.Descriptor(
  name='EngineReproduceRequest',
  full_name='EngineReproduceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine', full_name='EngineReproduceRequest.engine', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_name', full_name='EngineReproduceRequest.target_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testcase_path', full_name='EngineReproduceRequest.testcase_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='EngineReproduceRequest.arguments', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='EngineReproduceRequest.timeout', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5012,
  serialized_end=5132,
)

_SETUPREGULARBUILDREQUEST_TARGETWEIGHTSENTRY.containing_type = _SETUPREGULARBUILDREQUEST
_SETUPREGULARBUILDREQUEST.fields_by_name['target_weights'].message_type = _SETUPREGULARBUILDREQUEST_TARGETWEIGHTSENTRY
_RUNPROCESSREQUEST_ENVCOPYENTRY.containing_type = _RUNPROCESSREQUEST
_RUNPROCESSREQUEST.fields_by_name['env_copy'].message_type = _RUNPROCESSREQUEST_ENVCOPYENTRY
_POPENARGS_ENVENTRY.containing_type = _POPENARGS
_POPENARGS.fields_by_name['env'].message_type = _POPENARGS_ENVENTRY
_RUNANDWAITREQUEST.fields_by_name['popen_args'].message_type = _POPENARGS
_RUNANDWAITRESPONSE.fields_by_name['result'].message_type = _PROCESSRESULT
_UPDATEENVIRONMENTREQUEST_ENVENTRY.containing_type = _UPDATEENVIRONMENTREQUEST
_UPDATEENVIRONMENTREQUEST.fields_by_name['env'].message_type = _UPDATEENVIRONMENTREQUEST_ENVENTRY
_CROSSPOLLINATEFUZZER.fields_by_name['fuzz_target'].message_type = _FUZZTARGET
_PRUNECORPUSREQUEST.fields_by_name['fuzz_target'].message_type = _FUZZTARGET
_PRUNECORPUSREQUEST.fields_by_name['cross_pollinate_fuzzers'].message_type = _CROSSPOLLINATEFUZZER
_PRUNECORPUSRESPONSE.fields_by_name['coverage_info'].message_type = _COVERAGEINFO
_PRUNECORPUSRESPONSE.fields_by_name['crashes'].message_type = _CORPUSCRASH
_PRUNECORPUSRESPONSE.fields_by_name['cross_pollination_stats'].message_type = _CROSSPOLLINATIONSTATS
_PROCESSTESTCASEREQUEST.fields_by_name['operation'].enum_type = _PROCESSTESTCASEREQUEST_OPERATION
_PROCESSTESTCASEREQUEST_OPERATION.containing_type = _PROCESSTESTCASEREQUEST
_ENGINEFUZZRESPONSE_STATSENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ENGINEFUZZRESPONSE_STATSENTRY.containing_type = _ENGINEFUZZRESPONSE
_ENGINEFUZZRESPONSE_FUZZERMETADATAENTRY.containing_type = _ENGINEFUZZRESPONSE
_ENGINEFUZZRESPONSE_STRATEGIESENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ENGINEFUZZRESPONSE_STRATEGIESENTRY.containing_type = _ENGINEFUZZRESPONSE
_ENGINEFUZZRESPONSE.fields_by_name['crashes'].message_type = _ENGINECRASH
_ENGINEFUZZRESPONSE.fields_by_name['stats'].message_type = _ENGINEFUZZRESPONSE_STATSENTRY
_ENGINEFUZZRESPONSE.fields_by_name['fuzzer_metadata'].message_type = _ENGINEFUZZRESPONSE_FUZZERMETADATAENTRY
_ENGINEFUZZRESPONSE.fields_by_name['strategies'].message_type = _ENGINEFUZZRESPONSE_STRATEGIESENTRY
DESCRIPTOR.message_types_by_name['GetStatusRequest'] = _GETSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetStatusResponse'] = _GETSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['ProcessResult'] = _PROCESSRESULT
DESCRIPTOR.message_types_by_name['SetupBuildResponse'] = _SETUPBUILDRESPONSE
DESCRIPTOR.message_types_by_name['SetupRegularBuildRequest'] = _SETUPREGULARBUILDREQUEST
DESCRIPTOR.message_types_by_name['RunProcessRequest'] = _RUNPROCESSREQUEST
DESCRIPTOR.message_types_by_name['RunProcessResponse'] = _RUNPROCESSRESPONSE
DESCRIPTOR.message_types_by_name['PopenArgs'] = _POPENARGS
DESCRIPTOR.message_types_by_name['RunAndWaitRequest'] = _RUNANDWAITREQUEST
DESCRIPTOR.message_types_by_name['RunAndWaitResponse'] = _RUNANDWAITRESPONSE
DESCRIPTOR.message_types_by_name['FindBuildFileRequest'] = _FINDBUILDFILEREQUEST
DESCRIPTOR.message_types_by_name['FindBuildFileResponse'] = _FINDBUILDFILERESPONSE
DESCRIPTOR.message_types_by_name['CreateDirectoryRequest'] = _CREATEDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['CreateDirectoryResponse'] = _CREATEDIRECTORYRESPONSE
DESCRIPTOR.message_types_by_name['RemoveDirectoryRequest'] = _REMOVEDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['RemoveDirectoryResponse'] = _REMOVEDIRECTORYRESPONSE
DESCRIPTOR.message_types_by_name['FileChunk'] = _FILECHUNK
DESCRIPTOR.message_types_by_name['CopyFileToResponse'] = _COPYFILETORESPONSE
DESCRIPTOR.message_types_by_name['CopyFileFromRequest'] = _COPYFILEFROMREQUEST
DESCRIPTOR.message_types_by_name['UpdateEnvironmentRequest'] = _UPDATEENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateEnvironmentResponse'] = _UPDATEENVIRONMENTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSourceRequest'] = _UPDATESOURCEREQUEST
DESCRIPTOR.message_types_by_name['UpdateSourceResponse'] = _UPDATESOURCERESPONSE
DESCRIPTOR.message_types_by_name['SymbolizeStacktraceRequest'] = _SYMBOLIZESTACKTRACEREQUEST
DESCRIPTOR.message_types_by_name['SymbolizeStacktraceResponse'] = _SYMBOLIZESTACKTRACERESPONSE
DESCRIPTOR.message_types_by_name['ListFilesRequest'] = _LISTFILESREQUEST
DESCRIPTOR.message_types_by_name['ListFilesResponse'] = _LISTFILESRESPONSE
DESCRIPTOR.message_types_by_name['GetFuzzTargetsRequest'] = _GETFUZZTARGETSREQUEST
DESCRIPTOR.message_types_by_name['GetFuzzTargetsResponse'] = _GETFUZZTARGETSRESPONSE
DESCRIPTOR.message_types_by_name['CorpusCrash'] = _CORPUSCRASH
DESCRIPTOR.message_types_by_name['CoverageInfo'] = _COVERAGEINFO
DESCRIPTOR.message_types_by_name['CrossPollinateFuzzer'] = _CROSSPOLLINATEFUZZER
DESCRIPTOR.message_types_by_name['PruneCorpusRequest'] = _PRUNECORPUSREQUEST
DESCRIPTOR.message_types_by_name['PruneCorpusResponse'] = _PRUNECORPUSRESPONSE
DESCRIPTOR.message_types_by_name['StatRequest'] = _STATREQUEST
DESCRIPTOR.message_types_by_name['CrossPollinationStats'] = _CROSSPOLLINATIONSTATS
DESCRIPTOR.message_types_by_name['StatResponse'] = _STATRESPONSE
DESCRIPTOR.message_types_by_name['TerminateStaleApplicationInstancesRequest'] = _TERMINATESTALEAPPLICATIONINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['TerminateStaleApplicationInstancesResponse'] = _TERMINATESTALEAPPLICATIONINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['ResetEnvironmentRequest'] = _RESETENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['ResetEnvironmentResponse'] = _RESETENVIRONMENTRESPONSE
DESCRIPTOR.message_types_by_name['FuzzTarget'] = _FUZZTARGET
DESCRIPTOR.message_types_by_name['ProcessTestcaseRequest'] = _PROCESSTESTCASEREQUEST
DESCRIPTOR.message_types_by_name['EngineReproduceResult'] = _ENGINEREPRODUCERESULT
DESCRIPTOR.message_types_by_name['EngineFuzzRequest'] = _ENGINEFUZZREQUEST
DESCRIPTOR.message_types_by_name['EngineCrash'] = _ENGINECRASH
DESCRIPTOR.message_types_by_name['EngineFuzzResponse'] = _ENGINEFUZZRESPONSE
DESCRIPTOR.message_types_by_name['EngineReproduceRequest'] = _ENGINEREPRODUCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetStatusRequest = _reflection.GeneratedProtocolMessageType('GetStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATUSREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:GetStatusRequest)
  })
_sym_db.RegisterMessage(GetStatusRequest)

GetStatusResponse = _reflection.GeneratedProtocolMessageType('GetStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATUSRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:GetStatusResponse)
  })
_sym_db.RegisterMessage(GetStatusResponse)

ProcessResult = _reflection.GeneratedProtocolMessageType('ProcessResult', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSRESULT,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:ProcessResult)
  })
_sym_db.RegisterMessage(ProcessResult)

SetupBuildResponse = _reflection.GeneratedProtocolMessageType('SetupBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETUPBUILDRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:SetupBuildResponse)
  })
_sym_db.RegisterMessage(SetupBuildResponse)

SetupRegularBuildRequest = _reflection.GeneratedProtocolMessageType('SetupRegularBuildRequest', (_message.Message,), {

  'TargetWeightsEntry' : _reflection.GeneratedProtocolMessageType('TargetWeightsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SETUPREGULARBUILDREQUEST_TARGETWEIGHTSENTRY,
    '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
    # @@protoc_insertion_point(class_scope:SetupRegularBuildRequest.TargetWeightsEntry)
    })
  ,
  'DESCRIPTOR' : _SETUPREGULARBUILDREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:SetupRegularBuildRequest)
  })
_sym_db.RegisterMessage(SetupRegularBuildRequest)
_sym_db.RegisterMessage(SetupRegularBuildRequest.TargetWeightsEntry)

RunProcessRequest = _reflection.GeneratedProtocolMessageType('RunProcessRequest', (_message.Message,), {

  'EnvCopyEntry' : _reflection.GeneratedProtocolMessageType('EnvCopyEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNPROCESSREQUEST_ENVCOPYENTRY,
    '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
    # @@protoc_insertion_point(class_scope:RunProcessRequest.EnvCopyEntry)
    })
  ,
  'DESCRIPTOR' : _RUNPROCESSREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:RunProcessRequest)
  })
_sym_db.RegisterMessage(RunProcessRequest)
_sym_db.RegisterMessage(RunProcessRequest.EnvCopyEntry)

RunProcessResponse = _reflection.GeneratedProtocolMessageType('RunProcessResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNPROCESSRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:RunProcessResponse)
  })
_sym_db.RegisterMessage(RunProcessResponse)

PopenArgs = _reflection.GeneratedProtocolMessageType('PopenArgs', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _POPENARGS_ENVENTRY,
    '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
    # @@protoc_insertion_point(class_scope:PopenArgs.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _POPENARGS,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:PopenArgs)
  })
_sym_db.RegisterMessage(PopenArgs)
_sym_db.RegisterMessage(PopenArgs.EnvEntry)

RunAndWaitRequest = _reflection.GeneratedProtocolMessageType('RunAndWaitRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNANDWAITREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:RunAndWaitRequest)
  })
_sym_db.RegisterMessage(RunAndWaitRequest)

RunAndWaitResponse = _reflection.GeneratedProtocolMessageType('RunAndWaitResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNANDWAITRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:RunAndWaitResponse)
  })
_sym_db.RegisterMessage(RunAndWaitResponse)

FindBuildFileRequest = _reflection.GeneratedProtocolMessageType('FindBuildFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDBUILDFILEREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:FindBuildFileRequest)
  })
_sym_db.RegisterMessage(FindBuildFileRequest)

FindBuildFileResponse = _reflection.GeneratedProtocolMessageType('FindBuildFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDBUILDFILERESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:FindBuildFileResponse)
  })
_sym_db.RegisterMessage(FindBuildFileResponse)

CreateDirectoryRequest = _reflection.GeneratedProtocolMessageType('CreateDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDIRECTORYREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CreateDirectoryRequest)
  })
_sym_db.RegisterMessage(CreateDirectoryRequest)

CreateDirectoryResponse = _reflection.GeneratedProtocolMessageType('CreateDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDIRECTORYRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CreateDirectoryResponse)
  })
_sym_db.RegisterMessage(CreateDirectoryResponse)

RemoveDirectoryRequest = _reflection.GeneratedProtocolMessageType('RemoveDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDIRECTORYREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:RemoveDirectoryRequest)
  })
_sym_db.RegisterMessage(RemoveDirectoryRequest)

RemoveDirectoryResponse = _reflection.GeneratedProtocolMessageType('RemoveDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDIRECTORYRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:RemoveDirectoryResponse)
  })
_sym_db.RegisterMessage(RemoveDirectoryResponse)

FileChunk = _reflection.GeneratedProtocolMessageType('FileChunk', (_message.Message,), {
  'DESCRIPTOR' : _FILECHUNK,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:FileChunk)
  })
_sym_db.RegisterMessage(FileChunk)

CopyFileToResponse = _reflection.GeneratedProtocolMessageType('CopyFileToResponse', (_message.Message,), {
  'DESCRIPTOR' : _COPYFILETORESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CopyFileToResponse)
  })
_sym_db.RegisterMessage(CopyFileToResponse)

CopyFileFromRequest = _reflection.GeneratedProtocolMessageType('CopyFileFromRequest', (_message.Message,), {
  'DESCRIPTOR' : _COPYFILEFROMREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CopyFileFromRequest)
  })
_sym_db.RegisterMessage(CopyFileFromRequest)

UpdateEnvironmentRequest = _reflection.GeneratedProtocolMessageType('UpdateEnvironmentRequest', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEENVIRONMENTREQUEST_ENVENTRY,
    '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
    # @@protoc_insertion_point(class_scope:UpdateEnvironmentRequest.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEENVIRONMENTREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:UpdateEnvironmentRequest)
  })
_sym_db.RegisterMessage(UpdateEnvironmentRequest)
_sym_db.RegisterMessage(UpdateEnvironmentRequest.EnvEntry)

UpdateEnvironmentResponse = _reflection.GeneratedProtocolMessageType('UpdateEnvironmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENVIRONMENTRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:UpdateEnvironmentResponse)
  })
_sym_db.RegisterMessage(UpdateEnvironmentResponse)

UpdateSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESOURCEREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:UpdateSourceRequest)
  })
_sym_db.RegisterMessage(UpdateSourceRequest)

UpdateSourceResponse = _reflection.GeneratedProtocolMessageType('UpdateSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESOURCERESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:UpdateSourceResponse)
  })
_sym_db.RegisterMessage(UpdateSourceResponse)

SymbolizeStacktraceRequest = _reflection.GeneratedProtocolMessageType('SymbolizeStacktraceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLIZESTACKTRACEREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:SymbolizeStacktraceRequest)
  })
_sym_db.RegisterMessage(SymbolizeStacktraceRequest)

SymbolizeStacktraceResponse = _reflection.GeneratedProtocolMessageType('SymbolizeStacktraceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLIZESTACKTRACERESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:SymbolizeStacktraceResponse)
  })
_sym_db.RegisterMessage(SymbolizeStacktraceResponse)

ListFilesRequest = _reflection.GeneratedProtocolMessageType('ListFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILESREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:ListFilesRequest)
  })
_sym_db.RegisterMessage(ListFilesRequest)

ListFilesResponse = _reflection.GeneratedProtocolMessageType('ListFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILESRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:ListFilesResponse)
  })
_sym_db.RegisterMessage(ListFilesResponse)

GetFuzzTargetsRequest = _reflection.GeneratedProtocolMessageType('GetFuzzTargetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFUZZTARGETSREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:GetFuzzTargetsRequest)
  })
_sym_db.RegisterMessage(GetFuzzTargetsRequest)

GetFuzzTargetsResponse = _reflection.GeneratedProtocolMessageType('GetFuzzTargetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFUZZTARGETSRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:GetFuzzTargetsResponse)
  })
_sym_db.RegisterMessage(GetFuzzTargetsResponse)

CorpusCrash = _reflection.GeneratedProtocolMessageType('CorpusCrash', (_message.Message,), {
  'DESCRIPTOR' : _CORPUSCRASH,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CorpusCrash)
  })
_sym_db.RegisterMessage(CorpusCrash)

CoverageInfo = _reflection.GeneratedProtocolMessageType('CoverageInfo', (_message.Message,), {
  'DESCRIPTOR' : _COVERAGEINFO,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CoverageInfo)
  })
_sym_db.RegisterMessage(CoverageInfo)

CrossPollinateFuzzer = _reflection.GeneratedProtocolMessageType('CrossPollinateFuzzer', (_message.Message,), {
  'DESCRIPTOR' : _CROSSPOLLINATEFUZZER,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CrossPollinateFuzzer)
  })
_sym_db.RegisterMessage(CrossPollinateFuzzer)

PruneCorpusRequest = _reflection.GeneratedProtocolMessageType('PruneCorpusRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRUNECORPUSREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:PruneCorpusRequest)
  })
_sym_db.RegisterMessage(PruneCorpusRequest)

PruneCorpusResponse = _reflection.GeneratedProtocolMessageType('PruneCorpusResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRUNECORPUSRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:PruneCorpusResponse)
  })
_sym_db.RegisterMessage(PruneCorpusResponse)

StatRequest = _reflection.GeneratedProtocolMessageType('StatRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:StatRequest)
  })
_sym_db.RegisterMessage(StatRequest)

CrossPollinationStats = _reflection.GeneratedProtocolMessageType('CrossPollinationStats', (_message.Message,), {
  'DESCRIPTOR' : _CROSSPOLLINATIONSTATS,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:CrossPollinationStats)
  })
_sym_db.RegisterMessage(CrossPollinationStats)

StatResponse = _reflection.GeneratedProtocolMessageType('StatResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:StatResponse)
  })
_sym_db.RegisterMessage(StatResponse)

TerminateStaleApplicationInstancesRequest = _reflection.GeneratedProtocolMessageType('TerminateStaleApplicationInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATESTALEAPPLICATIONINSTANCESREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:TerminateStaleApplicationInstancesRequest)
  })
_sym_db.RegisterMessage(TerminateStaleApplicationInstancesRequest)

TerminateStaleApplicationInstancesResponse = _reflection.GeneratedProtocolMessageType('TerminateStaleApplicationInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATESTALEAPPLICATIONINSTANCESRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:TerminateStaleApplicationInstancesResponse)
  })
_sym_db.RegisterMessage(TerminateStaleApplicationInstancesResponse)

ResetEnvironmentRequest = _reflection.GeneratedProtocolMessageType('ResetEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETENVIRONMENTREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:ResetEnvironmentRequest)
  })
_sym_db.RegisterMessage(ResetEnvironmentRequest)

ResetEnvironmentResponse = _reflection.GeneratedProtocolMessageType('ResetEnvironmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETENVIRONMENTRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:ResetEnvironmentResponse)
  })
_sym_db.RegisterMessage(ResetEnvironmentResponse)

FuzzTarget = _reflection.GeneratedProtocolMessageType('FuzzTarget', (_message.Message,), {
  'DESCRIPTOR' : _FUZZTARGET,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:FuzzTarget)
  })
_sym_db.RegisterMessage(FuzzTarget)

ProcessTestcaseRequest = _reflection.GeneratedProtocolMessageType('ProcessTestcaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSTESTCASEREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:ProcessTestcaseRequest)
  })
_sym_db.RegisterMessage(ProcessTestcaseRequest)

EngineReproduceResult = _reflection.GeneratedProtocolMessageType('EngineReproduceResult', (_message.Message,), {
  'DESCRIPTOR' : _ENGINEREPRODUCERESULT,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:EngineReproduceResult)
  })
_sym_db.RegisterMessage(EngineReproduceResult)

EngineFuzzRequest = _reflection.GeneratedProtocolMessageType('EngineFuzzRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENGINEFUZZREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:EngineFuzzRequest)
  })
_sym_db.RegisterMessage(EngineFuzzRequest)

EngineCrash = _reflection.GeneratedProtocolMessageType('EngineCrash', (_message.Message,), {
  'DESCRIPTOR' : _ENGINECRASH,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:EngineCrash)
  })
_sym_db.RegisterMessage(EngineCrash)

EngineFuzzResponse = _reflection.GeneratedProtocolMessageType('EngineFuzzResponse', (_message.Message,), {

  'StatsEntry' : _reflection.GeneratedProtocolMessageType('StatsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENGINEFUZZRESPONSE_STATSENTRY,
    '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
    # @@protoc_insertion_point(class_scope:EngineFuzzResponse.StatsEntry)
    })
  ,

  'FuzzerMetadataEntry' : _reflection.GeneratedProtocolMessageType('FuzzerMetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENGINEFUZZRESPONSE_FUZZERMETADATAENTRY,
    '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
    # @@protoc_insertion_point(class_scope:EngineFuzzResponse.FuzzerMetadataEntry)
    })
  ,

  'StrategiesEntry' : _reflection.GeneratedProtocolMessageType('StrategiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENGINEFUZZRESPONSE_STRATEGIESENTRY,
    '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
    # @@protoc_insertion_point(class_scope:EngineFuzzResponse.StrategiesEntry)
    })
  ,
  'DESCRIPTOR' : _ENGINEFUZZRESPONSE,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:EngineFuzzResponse)
  })
_sym_db.RegisterMessage(EngineFuzzResponse)
_sym_db.RegisterMessage(EngineFuzzResponse.StatsEntry)
_sym_db.RegisterMessage(EngineFuzzResponse.FuzzerMetadataEntry)
_sym_db.RegisterMessage(EngineFuzzResponse.StrategiesEntry)

EngineReproduceRequest = _reflection.GeneratedProtocolMessageType('EngineReproduceRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENGINEREPRODUCEREQUEST,
  '__module__' : 'clusterfuzz._internal.protos.untrusted_runner_pb2'
  # @@protoc_insertion_point(class_scope:EngineReproduceRequest)
  })
_sym_db.RegisterMessage(EngineReproduceRequest)


DESCRIPTOR._options = None
_SETUPREGULARBUILDREQUEST_TARGETWEIGHTSENTRY._options = None
_RUNPROCESSREQUEST_ENVCOPYENTRY._options = None
_POPENARGS_ENVENTRY._options = None
_UPDATEENVIRONMENTREQUEST_ENVENTRY._options = None
_ENGINEFUZZRESPONSE_STATSENTRY._options = None
_ENGINEFUZZRESPONSE_FUZZERMETADATAENTRY._options = None
_ENGINEFUZZRESPONSE_STRATEGIESENTRY._options = None

_UNTRUSTEDRUNNER = _descriptor.ServiceDescriptor(
  name='UntrustedRunner',
  full_name='UntrustedRunner',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5135,
  serialized_end=6448,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='UntrustedRunner.GetStatus',
    index=0,
    containing_service=None,
    input_type=_GETSTATUSREQUEST,
    output_type=_GETSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetupRegularBuild',
    full_name='UntrustedRunner.SetupRegularBuild',
    index=1,
    containing_service=None,
    input_type=_SETUPREGULARBUILDREQUEST,
    output_type=_SETUPBUILDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunProcess',
    full_name='UntrustedRunner.RunProcess',
    index=2,
    containing_service=None,
    input_type=_RUNPROCESSREQUEST,
    output_type=_RUNPROCESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunAndWait',
    full_name='UntrustedRunner.RunAndWait',
    index=3,
    containing_service=None,
    input_type=_RUNANDWAITREQUEST,
    output_type=_RUNANDWAITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDirectory',
    full_name='UntrustedRunner.CreateDirectory',
    index=4,
    containing_service=None,
    input_type=_CREATEDIRECTORYREQUEST,
    output_type=_CREATEDIRECTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveDirectory',
    full_name='UntrustedRunner.RemoveDirectory',
    index=5,
    containing_service=None,
    input_type=_REMOVEDIRECTORYREQUEST,
    output_type=_REMOVEDIRECTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFiles',
    full_name='UntrustedRunner.ListFiles',
    index=6,
    containing_service=None,
    input_type=_LISTFILESREQUEST,
    output_type=_LISTFILESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CopyFileTo',
    full_name='UntrustedRunner.CopyFileTo',
    index=7,
    containing_service=None,
    input_type=_FILECHUNK,
    output_type=_COPYFILETORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CopyFileFrom',
    full_name='UntrustedRunner.CopyFileFrom',
    index=8,
    containing_service=None,
    input_type=_COPYFILEFROMREQUEST,
    output_type=_FILECHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stat',
    full_name='UntrustedRunner.Stat',
    index=9,
    containing_service=None,
    input_type=_STATREQUEST,
    output_type=_STATRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEnvironment',
    full_name='UntrustedRunner.UpdateEnvironment',
    index=10,
    containing_service=None,
    input_type=_UPDATEENVIRONMENTREQUEST,
    output_type=_UPDATEENVIRONMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetEnvironment',
    full_name='UntrustedRunner.ResetEnvironment',
    index=11,
    containing_service=None,
    input_type=_RESETENVIRONMENTREQUEST,
    output_type=_RESETENVIRONMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSource',
    full_name='UntrustedRunner.UpdateSource',
    index=12,
    containing_service=None,
    input_type=_UPDATESOURCEREQUEST,
    output_type=_UPDATESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SymbolizeStacktrace',
    full_name='UntrustedRunner.SymbolizeStacktrace',
    index=13,
    containing_service=None,
    input_type=_SYMBOLIZESTACKTRACEREQUEST,
    output_type=_SYMBOLIZESTACKTRACERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TerminateStaleApplicationInstances',
    full_name='UntrustedRunner.TerminateStaleApplicationInstances',
    index=14,
    containing_service=None,
    input_type=_TERMINATESTALEAPPLICATIONINSTANCESREQUEST,
    output_type=_TERMINATESTALEAPPLICATIONINSTANCESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFuzzTargets',
    full_name='UntrustedRunner.GetFuzzTargets',
    index=15,
    containing_service=None,
    input_type=_GETFUZZTARGETSREQUEST,
    output_type=_GETFUZZTARGETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PruneCorpus',
    full_name='UntrustedRunner.PruneCorpus',
    index=16,
    containing_service=None,
    input_type=_PRUNECORPUSREQUEST,
    output_type=_PRUNECORPUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProcessTestcase',
    full_name='UntrustedRunner.ProcessTestcase',
    index=17,
    containing_service=None,
    input_type=_PROCESSTESTCASEREQUEST,
    output_type=_ENGINEREPRODUCERESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EngineFuzz',
    full_name='UntrustedRunner.EngineFuzz',
    index=18,
    containing_service=None,
    input_type=_ENGINEFUZZREQUEST,
    output_type=_ENGINEFUZZRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EngineReproduce',
    full_name='UntrustedRunner.EngineReproduce',
    index=19,
    containing_service=None,
    input_type=_ENGINEREPRODUCEREQUEST,
    output_type=_ENGINEREPRODUCERESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_UNTRUSTEDRUNNER)

DESCRIPTOR.services_by_name['UntrustedRunner'] = _UNTRUSTEDRUNNER

# @@protoc_insertion_point(module_scope)
